<?php
namespace App\JsonRpc;
use App\Model\User;
use App\Model\UserInfo;
use App\Model\UserLogin;
use Hyperf\RpcServer\Annotation\RpcService;
use App\Tools\Result;
use Hyperf\DbConnection\Db;
#[RpcService(name: "UserService", protocol: "jsonrpc-http", server: "jsonrpc-http")]
class UserService implements UserServiceInterface
{
    /**
     * @param string $name
     * @param int $gender
     * @return string
     */
    public function createUser(array $data): array
    {
        Db::beginTransaction();
        try{

            $dataUserReq = [
                'user_name'=>$data['user_name'],
                'password'=>md5(md5($data['password']).$data['salt']),
                'avatar'=>$data['avatar'],
                'mobile'=>$data['mobile'],
                'status'=>isset($data['status'])?$data['status']:1,
                'role_id'=>$data['role_id']?$data['role_id']:0,
                'email'=>$data['email']?$data['email']:'',
                'salt'=>$data['salt'],
                'rong_token'=>$data['rong_token'],
                'level_id'=>$data['level_id'], //会员等级
            ];
            $userid = User::query()->insertGetId($dataUserReq);
            $dataUserInfoReq = [
                'user_id'=>$userid,
                'id_card'=>$data['id_card'],
                'gender'=>$data['gender']?$data['gender']:0,
                'real_name'=>$data['real_name'],
            ];
            if($data['birthday']){
                array_push($dataUserInfoReq,[ 'birthday'=>$data['birthday']]);
            }

            $userInfoId = UserInfo::query()->insertGetId($dataUserInfoReq);
            var_dump("userInfo",$userInfoId);
            Db::commit();
        } catch(\Throwable $ex){
            Db::rollBack();
            var_dump($ex->getMessage());
            return Result::error("创建失败",0);
        }
        return $userInfoId ? Result::success(["id"=>$userid]) : Result::error("创建失败",0);
    }
    /**
     * @param int $id
     * @return array
     */
    public function getUserInfo(int $id): array
    {
        $userInfo =  Db::table('user')
            ->leftJoin('user_info', 'user.id', '=', 'user_info.user_id')
            ->select('user.*', 'user_info.id as user_info_id','user_info.id_card','user_info.birthday','user_info.gender','user_info.real_name')
            ->where('user.id','=',$id)->first();
        if (empty($userInfo)) {
           return Result::error("找不到用户",0,[]);
        }

        return Result::success($userInfo);
    }

    /**
     * @param array $data
     * @return array
     */
    public function verifyUserInfo(array $data): array
    {
        $userInfo = User::query()->where($data)->first();
        if (empty($userInfo)) {
            return Result::error("找不到用户",0);
        }
        return Result::success($userInfo->toArray());
    }

    /**
     * @param array $data
     * @return array
     */
    public function createUserLogin(array $data): array
    {
       $id =  UserLogin::insertGetId($data);
        if (empty($id)) {
            return Result::error("创建登录日志失败",0);
        }
        return Result::success(["id"=>$id]);
    }

    /**
     * 更新用户信息和userInfo
     * @param array $data
     * @return array
     */
    public function updateUser(array $data): array{
        Db::beginTransaction();
        try{
            $dataUserReq = [
                'user_name'=>$data['user_name'],
                'password'=>md5(md5($data['password']).$data['salt']),
                'avatar'=>$data['avatar'],
                'mobile'=>$data['mobile'],
                'status'=>isset($data['status'])?$data['status']:1,
                'role_id'=>$data['role_id']?$data['role_id']:0,
                'email'=>$data['email']?$data['email']:'',
                'salt'=>$data['salt'],
                'rong_token'=>$data['rong_token'],
                'level_id'=>$data['level_id'], //会员等级
            ];
            $userRep =  User::where(['id'=>$data['id']])->update($dataUserReq);

            $dataUserInfoReq = [
                'user_id'=>$data['id'],
                'id_card'=>$data['id_card'],
                'gender'=>$data['gender']?$data['gender']:0,
                'real_name'=>$data['real_name'],
            ];

            $userRep =  UserInfo::where(['user_id'=>$data['id']])->update($dataUserInfoReq);

            Db::commit();
        } catch(\Throwable $ex){
            Db::rollBack();
            var_dump($ex->getMessage());
            return Result::error("创建失败",0);
        }
        return Result::success([]);
    }

    /**
     * @param array $data
     * @return array
     */
    public function updateUserInfo(array $data): array{
        return 1;
    }

    /**
     * @param int $id
     * @return array
     */
    public function  delUser(int $id) :array{
        Db::beginTransaction();
        try{
            User::where(['id'=>$id])->delete();
            UserInfo::where(['user_id'=>$id])->delete();
            Db::commit();
        } catch(\Throwable $ex){
            Db::rollBack();
            return Result::error("删除失败",0);
        }
        return Result::success([]);

    }


}